@@ -6,14 +6,14 @@
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsd6.0"
+#define HOST_OS "freebsd6.1"
 #define HOST_OS_NAME "freebsd6"
-#define HOST_OS_VERSION "6.0"
+#define HOST_OS_VERSION "6.1"
 #define HOST_ARCH "i386"
 #define DISTRO_NAME "none"
-#define HOST_NAME "a-freebsd60.fsl.cs.sunysb.edu"
+#define HOST_NAME "a-freebsd61.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Wed May 10 10:52:38 EDT 2006"
+#define CONFIG_DATE "Wed May 10 15:53:14 EDT 2006"
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_VERSION "6.2a2"
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
@@ -34,7 +34,7 @@
 #ifdef __cplusplus
 #include <stdlib.h>
 #endif
-#define HOST_HEADER_VERSION "6.0"
+#define HOST_HEADER_VERSION "6.1"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_UNISTD_H 1
@@ -202,7 +202,6 @@
 #define HAVE_SYS_STAT_H 1
 #define HAVE_SYS_STATVFS_H 1
 #define HAVE_SYS_SYSCALL_H 1
-#define HAVE_SYS_SYSLIMITS_H 1
 #define HAVE_SYS_SYSLOG_H 1
 #define HAVE_SYS_TIME_H 1
 #define HAVE_SYS_TYPES_H 1
@@ -318,13 +317,21 @@
 #define HAVE_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_STRUCT_SOCKADDR_SA_LEN 1
+#define HAVE_FGETS 1
 #define HAVE_MAP_FILE 1
+#define HAVE_FGETS 1
 #define HAVE_MAP_SUN 1
+#define HAVE_WAITPID 1
 #define HAVE_MAP_EXEC 1
+#define HAVE_HES_INIT 1
 #define HAVE_MAP_HESIOD 1
+#define HAVE_DBM_OPEN 1
 #define HAVE_MAP_NDBM 1
+#define HAVE_YP_GET_DEFAULT_DOMAIN 1
 #define HAVE_MAP_NIS 1
+#define HAVE_GETPWNAM 1
 #define HAVE_MAP_PASSWD 1
+#define HAVE_OPENDIR 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_NFS 1
@@ -350,7 +357,7 @@
 #define MOUNT_TYPE_IGNORE MNT_IGNORE
 #define MOUNT_TYPE_UNIONFS MNT_UNION
 #define MNTTAB_TYPE_NFS "nfs"
-#define MNTTAB_TYPE_NFS3 "nfs3"
+#define MNTTAB_TYPE_NFS3 "nfs"
 #define MNTTAB_TYPE_UFS "ufs"
 #define MNTTAB_TYPE_CDFS "cd9660"
 #define MNTTAB_TYPE_PCFS "msdosfs"
@@ -390,5 +397,6 @@
 #define MNT2_PCFS_OPT_NOWIN95 0x4
 #define MNT2_PCFS_OPT_SHORTNAME 0x1
 #define HIDE_MOUNT_TYPE "nfs"
+#define HAVE_GETMNTINFO 1
 #define USE_CONNECTED_NFS_SOCKETS 1
 #define HAVE_LIBWRAP 1
